from .validator import Validator, ValidationError, StopValidation
from .accepted import Accepted
from .alpha import Alpha
from .alphaDash import AlphaDash
from .alphaNum import AlphaNum
from .between import Between
from .boolean import Boolean
from .required import Required
from .size import Size



from typing import Union
from .validator import Validator, ValidationError


class Size(Validator):
    def __init__(self, length: int, message: Union[str, None] = None) -> None:
        self.size = length
        self.message = message or 'The :attribute must be :size characters.'

    def __call__(self, request, value):
        if len(value) != self.size:
            raise ValidationError(self.message)
        return value



from .validator import Validator, ValidationError, StopValidation


class Required(Validator):
    message = 'This field is required'

    def __call__(self, request, value):
        if value is None or len(value) == 0:
            raise StopValidation(self.message)
        return value
